@@ -1,6 +1,6 @@
 package WebService::KoreanSpeller;
-# ABSTRACT: Korean spellchecker
-our $VERSION = '0.010';
+
+our $VERSION = '0.011';
 $VERSION = eval $VERSION;
 
 use Moose;
@@ -63,10 +63,6 @@ __END__
 
 WebService::KoreanSpeller - Korean spellchecker
 
-=head1 VERSION
-
-version 0.010
-
 =head1 SYNOPSIS
 
     use WebService::KoreanSpeller;
@@ -101,14 +97,6 @@ version 0.010
 
 This module provides a Perl interface to the Web-based korean speller service( 온라인 한국어 맞춤법/문법 검사기 - http://speller.cs.pusan.ac.kr ).
 
-=head1 NAME
-
-WebService::KoreanSpeller - Korean spellchecker
-
-=head1 VERSION
-
-version 0.009
-
 =head1 METHODS
 
 =head2 new( text => 'text for spell check' )
@@ -134,15 +122,4 @@ This software is copyright (c) 2012 by C.H. Kang.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-C.H. Kang <chahkang@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by C.H. Kang.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
